/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.hadoop.hdfs.server.datanode;

import java.io.IOException;

import org.apache.hadoop.hdfs.server.datanode.FSDatasetInterface.BlockWriteStreams;

/** 
 * This defines the interface of a replica in Pipeline that's being written to
 */
interface ReplicaInPipelineInterface extends Replica {
  /**
   * Set the number of bytes received
   * @param bytesReceived number of bytes received
   */
  void setNumBytes(long bytesReceived);
  
  /**
   * Get the number of bytes acked
   * @return the number of bytes acked
   */
  long getBytesAcked();
  
  /**
   * Set the number bytes that have acked
   * @param bytesAcked
   */
  void setBytesAcked(long bytesAcked);
  
  /**
   * Set the number of bytes on disk
   * @param bytesOnDisk number of bytes on disk
   */
  void setBytesOnDisk(long bytesOnDisk);
  
  /**
   * Create output streams for writing to this replica, 
   * one for block file and one for CRC file
   * 
   * @return output streams for writing
   * @throws IOException if any error occurs
   */
  public BlockWriteStreams createStreams() throws IOException;
}
